//------------------------------------------------------------
// Copyright (C)2002 Sony Computer Entertainment America Inc.
//
// This file is subject to the terms and conditions of the GNU
// General Public Licence Version 2.  See the file "COPYING"
// in the main directory of this archive for more details.
//------------------------------------------------------------

/**********************************************************************************
Coombseys dlib_file.c
05/1/00
Description:
dlib = daves library
This is very basic stuff used for file loading
**********************************************************************************/

#include <stdlib.h>
#include <stdio.h>
#include <malloc.h>

#include "dlib_file.h"

//---------------------------------------------------------------------------
// This is a super simple file loading function.
// On success, returns a pointer to the file loaded in memory
// On failure returns a NULL pointer
// Sets bytes to be the number of bytes loaded
//---------------------------------------------------------------------------
void *dc_read_file (char *filename, u_int *bytes)
{
   FILE  *fp;          // file handle
   int   len;          // length of the file
   char  *cp;

   // Open the file for reading
   fp = fopen (filename, "rb");
   if (fp == NULL)
   {
      printf ("Could not locate file '%s'\n", filename);
      return (NULL);
   }

   // Work out the size of the file
   if (fseek (fp, 0, SEEK_END) != 0)
   {
      printf ("Could not get the file size '%s'\n", filename);
      fclose (fp);
      return (NULL);
   }

   len = ftell (fp);

   if (fseek (fp, 0, SEEK_SET) != 0)
   {
      printf ("Could not get the file size '%s'\n", filename);
      fclose (fp);
      return (NULL);
   }

   printf ("'%s' filesize = %d\n", filename, len);

   // Allocate memory for loading
   cp = (char *)memalign (128, (len + 15) & ~15);
   //cp = (char *)malloc(len); //allocate memory for load

   if (cp == NULL)
   {
      printf ("Could not allocate memory to load file '%s'\n", filename);
      return (NULL);
   }

   if (fread (cp, 1, len, fp) != len)
   {
      // Free the memory that was allocated, don't need it anymore
      free (cp);
      printf ("Failed to load file '%s'\n", filename);
      return (NULL);
   }

   *bytes = len;

   fclose (fp);

   return (cp);
}

//---------------------------------------------------------------------------
// This is a super simple file writing function
// Returns bytes written
//---------------------------------------------------------------------------
int dc_write_file (char *filename,  // File to create and write
                   char *cp,        // Buffer to write from
                   int  len)        // Bytes to write
{
   FILE  *fp;              // File handle

   // Open the file for writing
   fp = fopen (filename, "wb");
   if (fp == NULL)
   {
      printf ("Could not create file '%s'\n", filename);
      return (0);
   }

   if (fwrite (cp, 1, len, fp) != len)
   {
      printf ("Failed to write file '%s'\n", filename);
      return (0);
   }

   fclose (fp);

   return (len);
}
